@@ -33,9 +33,10 @@
 #  define KDELIBS4SUPPORT_DEPRECATED_NO_EXPORT KDELIBS4SUPPORT_NO_EXPORT KDELIBS4SUPPORT_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KDELIBS4SUPPORT_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KDELIBS4SUPPORT_NO_DEPRECATED
+#    define KDELIBS4SUPPORT_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
